==> owncloud-10.2.0.zip: owncloud/apps/files_sharing/l10n/sq.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Ndarja mes shërbyesish s’është e aktivizuar në këtë shërbyes",
    "The mountpoint name contains invalid characters." : "Emri i pikës së montimit përmban shenja të pavlefshme.",
    "Not allowed to create a federated share with the same user server" : "Nuk i lejohet të krijojë një ndarje të federuar me të njëjtin shërbyes përdoruesi",
    "Invalid or untrusted SSL certificate" : "Dëshmi SSL e pavlefshme ose e pabesuar",
    "Could not authenticate to remote share, password might be wrong" : "S’bëri dot mirëfilltësimin te ndarja e largët, fjalëkalimi mund të jetë i gabuar",
    "Storage not valid" : "Depozitë jo e vlefshme",
    "Couldn't add remote share" : "S’shtoi dotë ndarje të largët",
    "Shared with you" : "Të ndara me ju",
    "Shared with others" : "Të ndara me të tjerët",
    "Shared by link" : "Të ndara me lidhje",
    "Anonymous upload" : "Ngarkim anonim",
    "Click to select files or use drag & drop to upload" : "Klikoni që të përzgjidhni kartela ose përdorni teknikën merr & vër që të ngarkoni",
    "Uploaded files" : "Kartela të ngarkuara",
    "Uploading..." : "Po ngarkohet...",
    "Nothing shared with you yet" : "Ende pa ndarë gjë me ju",
    "Files and folders others share with you will show up here" : "Këtu do të shfaqen kartelat dhe dosjet që të jerët ndajnë me ju",
    "Nothing shared yet" : "Ende pa ndarë gjë",
    "Files and folders you share will show up here" : "Këtu do të shfaqen kartelat dhe dosjet që ndani me të tjerët",
    "No shared links" : "Pa lidhje ndarjesh",
    "Files and folders you share by link will show up here" : "Këtu do të shfaqen kartelat dhe dosjet që ndani përmes lidhjesh",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Doni të shtohet ndarja e largët {name} nga {owner}@{remote}?",
    "Remote share" : "Ndarje e largët",
    "Remote share password" : "Fjalëkalim ndarjeje të largët",
    "Cancel" : "Anuloje",
    "Add remote share" : "Shtoni ndarje të largët",
    "You can upload into this folder" : "Mund të ngarkoni te kjo dosje",
    "No ownCloud installation (7 or higher) found at {remote}" : "Te {remote} s’u gjet instalim ownCloud (7 ose më sipër)",
    "Invalid ownCloud url" : "URL ownCloud e pavlefshme",
    "Share" : "Ndaje",
    "No expiration date set" : "S’ka të caktuar datë skadimi",
    "Shared by" : "Ndarë nga",
    "Sharing" : "Ndarje",
    "Share API is disabled" : "API i ndarjeve është çaktivizuar",
    "Wrong share ID, share doesn't exist" : "ID e gabuar ndarjeje, ndarja s’ekziston",
    "Could not delete share" : "Ndarja s’u fshi dot",
    "Please specify a file or folder path" : "Ju lutemi, tregoni një shteg kartele ose dosjeje",
    "Wrong path, file/folder doesn't exist" : "Shteg i gabuar, kratela/dosja s’ekziston",
    "Cannot remove all permissions" : "S’mund të hiqen krejt lejet",
    "Please specify a valid user" : "Ju lutemi, tregoni një përdorues të vlefshëm",
    "Group sharing is disabled by the administrator" : "Ndarja në grup është çaktivizuar nga përgjegjësi",
    "Please specify a valid group" : "Ju lutemi, tregoni një grup të vlefshëm",
    "Public link sharing is disabled by the administrator" : "Ndarja e lidhjeve publike është çaktivizuar nga përgjegjësi",
    "Public upload disabled by the administrator" : "Ngarkimi publik është çaktivizuar nga përgjegjësi",
    "Public upload is only possible for publicly shared folders" : "Ngarkimi publik është i mundshëm vetëm për dosje të ndara publikisht",
    "Invalid date, date format must be YYYY-MM-DD" : "Datë e pavlefshme, formati i datës duhet të jetë VVVV-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Ndarja e %s dështoi, ngaqë pjesa përgjegjëse e shërbyesit nuk lejon ndarje prej llojit %s",
    "Unknown share type" : "Lloj i panjohur ndarjesh",
    "Not a directory" : "S’është drejtori",
    "Could not lock path" : "S’u kyç dot shtegu",
    "Can't change permissions for public share links" : "S’mund të ndryshohen lejet për lidhje ndarjesh publike",
    "Wrong or no update parameter given" : "Ose u dha parametër i gabuar përditësimesh, pse s’u dha fare ",
    "Cannot increase permissions" : "S’mund të fuqizohen lejet",
    "A file or folder has been <strong>shared</strong>" : "U <strong>nda me të tjerë</strong> një kartelë ose dosje",
    "A file or folder was shared from <strong>another server</strong>" : "Një kartelë ose dosje u nda prej një <strong>shërbyesi tjetër</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "<strong>U shkarkua</strong> një kartelë ose dosje e ndarë me të tjerët publikisht",
    "You received a new remote share %2$s from %1$s" : "Morët një ndarje të largët %2$s nga %1$s",
    "You received a new remote share from %s" : "Morët një ndarje të largët nga %s",
    "%1$s accepted remote share %2$s" : "%1$s pranoi ndarjen e largët %2$s",
    "%1$s declined remote share %2$s" : "%1$s hodhi tej ndarjen e largët %2$s",
    "%1$s unshared %2$s from you" : "%1$s shndau me ju %2$s",
    "Public shared folder %1$s was downloaded" : "U shkarkua dosja e ndarë publikisht %1$s",
    "Public shared file %1$s was downloaded" : "U shkarkua kartela e ndarë publikisht %1$s",
    "You shared %1$s with %2$s" : "Ndatë %1$s me %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s ndau %1$s me %3$s",
    "You removed the share of %2$s for %1$s" : "Hoqët ndarjen e %2$s për %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s hoqi ndarjen e %3$s për %1$s",
    "You shared %1$s with group %2$s" : "Ndatë %1$s me grupin %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s ndau %1$s me grupin %3$s",
    "You removed the share of group %2$s for %1$s" : "Hoqët ndarjen e grupit %2$s për %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s hoqi ndarjen e grupit %3$s për %1$s",
    "%2$s shared %1$s via link" : "%2$s ndau %1$s përmes një lidhjeje",
    "You shared %1$s via link" : "Ndatë %1$s përmes një lidhjeje",
    "You removed the public link for %1$s" : "Hoqët lidhjen publike për %1$s",
    "%2$s removed the public link for %1$s" : "%2$s hoqi lidhjen publike për %1$s",
    "Your public link for %1$s expired" : "Lidhja juaj publike për %1$s skadoi",
    "The public link of %2$s for %1$s expired" : "Lidhja publike e %2$s për %1$s skadoi",
    "%2$s shared %1$s with you" : "%2$s ndau %1$s me ju",
    "%2$s removed the share for %1$s" : "%2$s hoqi ndarjen për %1$s",
    "Downloaded via public link" : "Shkarkuar përmes një lidhjeje publike",
    "Shared with %2$s" : "U nda me %2$s",
    "Shared with %3$s by %2$s" : "U nda me %3$s nga %2$s",
    "Removed share for %2$s" : "Hoqi ndarjen për %2$s",
    "%2$s removed share for %3$s" : "%2$s hoqi ndarjen për %3$s",
    "Shared with group %2$s" : "U nda me grupin %2$s",
    "Shared with group %3$s by %2$s" : "U nda me grupin %3$s nga %2$s",
    "Removed share of group %2$s" : "Hoqi ndarjen e grupit %2$s",
    "%2$s removed share of group %3$s" : "%2$s hoqi ndarjen e grupit %3$s",
    "Shared via link by %2$s" : "U nda përmes një lidhje nga %2$s",
    "Shared via public link" : "U nda përmes një lidhje publike",
    "Removed public link" : "Hoqi lidhje publike",
    "%2$s removed public link" : "%2$s hoqi lidhje publike",
    "Public link expired" : "Lidhja publike skadoi",
    "Public link of %2$s expired" : "Lidhja publike e %2$s skadoi",
    "Shared by %2$s" : "U nda nga %2$s",
    "Shares" : "Ndarje",
    "This share is password-protected" : "Kjo pjesë është e mbrojtur me fjalëkalim",
    "The password is wrong. Try again." : "Fjalëkalimi është i gabuar. Riprovoni.",
    "Password" : "Fjalëkalim",
    "No entries found in this folder" : "S’u gjetën zëra në këtë dosje",
    "Name" : "Emër",
    "Share time" : "Kohë ndarjeje",
    "Expiration date" : "Datë skadimi",
    "Sorry, this link doesn’t seem to work anymore." : "Na ndjeni, kjo lidhje duket se nuk funksionon më.",
    "Reasons might be:" : "Arsyet mund të jenë:",
    "the item was removed" : "objekti është hequr",
    "the link expired" : "lidhja ka skaduar",
    "sharing is disabled" : "ndarjet janë çaktivizuar",
    "For more info, please ask the person who sent this link." : "Për më shumë të dhëna, ju lutemi, pyetni personin që ju dërgoi këtë lidhje.",
    "%s is publicly shared" : "%s ndahet publikisht me të tjerët",
    "Add to your ownCloud" : "Shtojeni te ownCloud-i juaj",
    "Download" : "Shkarko",
    "Download %s" : "Shkarko %s",
    "Direct link" : "Lidhje e drejtpërdrejtë",
    "No permission to create share" : "S’ka leje për krijim ndarjeje",
    "Pending" : "Në pritje",
    "Accept" : "Pranoje",
    "Decline" : "Hidhe poshtë",
    "Declined" : "Hedhur Poshtë",
    "An error occurred while updating share state: {message}" : "Ndodhi një gabim teksa përditësohej gjendja e ndarjes: {message}",
    "Accept Share" : "Pranoje Ndarjen",
    "Decline Share" : "Hidhe Poshtë Ndarjen",
    "Only recipient can change accepted state" : "Gjendjen e pranimit mund ta ndryshojnë vetëm marrësi",
    "File sharing" : "Ndarje kartelash me të tjerët",
    "State" : "Gjendje",
    "The group is blacklisted for sharing" : "Grupit i është ndaluar shkëmbimi",
    "Files Sharing" : "Shkëmbim Kartelash",
    "Exclude groups from receiving shares." : "Përjashtoni grupe nga marrje ndarjesh me të tjerë.",
    "These groups will not receive shares. Members of the group can still send and receive shares outside of the group." : "Këto grupe nuk do të marrin ndarje. Anëtarët e grupit munden prapëseprapë të dërgojnë dhe marrin ndarje jashtë grupit.",
    "Group Sharing Blacklist" : "Listë Bllokimesh Grupesh Ndarjesh",
    "Exclude groups from receiving shares" : "Përjashto grupe nga marrje ndarjesh",
    "These groups will not be available to share with. Members of the group are not restricted in initiating shares and can receive shares with other groups they are a member of as usual." : "Për këto grupe nuk do të jetë e mundur të ndajnë me të tjerët. Anëtarët e grupit nuk janë të kufizuar të nisin ndarje dhe mund të marrin ndarje me grupe të tjerë te të cilët janë anëtarë, si zakonisht.",
    "Public link" : "Lidhje publike",
    "Couldn't send mail to following recipient(s): %s " : "S’u dërgua dot postë te marrësi(t) vijues: %s "
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.4.0.zip: owncloud/apps/files_sharing/l10n/sq.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Ndarja mes shërbyesish s’është e aktivizuar në këtë shërbyes",
    "The mountpoint name contains invalid characters." : "Emri i pikës së montimit përmban shenja të pavlefshme.",
    "Not allowed to create a federated share with the same user server" : "S’ka leje të krijojë një ndarje të federuar me të njëjtin shërbyes përdoruesi",
    "Invalid or untrusted SSL certificate" : "Dëshmi SSL e pavlefshme ose e pabesuar",
    "Could not authenticate to remote share, password might be wrong" : "S’bëri dot mirëfilltësimin te ndarja e largët, fjalëkalimi mund të jetë i gabuar",
    "Storage not valid" : "Depozitë jo e vlefshme",
    "Couldn't add remote share" : "S’shtoi dot ndarje të largët",
    "Shared with you" : "Të ndara me ju",
    "Shared with others" : "Të ndara me të tjerët",
    "Shared by link" : "Të ndara me lidhje",
    "Anonymous upload" : "Ngarkim anonim",
    "Click to select files or use drag & drop to upload" : "Klikoni që të përzgjidhni kartela ose përdorni teknikën merr & vër që të ngarkoni",
    "Uploaded files" : "Kartela të ngarkuara",
    "Uploading..." : "Po ngarkohet...",
    "Nothing shared with you yet" : "Ende pa ndarë gjë me ju",
    "Files and folders others share with you will show up here" : "Këtu do të shfaqen kartelat dhe dosjet që të jerët ndajnë me ju",
    "Nothing shared yet" : "Ende pa ndarë gjë",
    "Files and folders you share will show up here" : "Këtu do të shfaqen kartelat dhe dosjet që ndani me të tjerët",
    "No shared links" : "Pa lidhje ndarjesh",
    "Files and folders you share by link will show up here" : "Këtu do të shfaqen kartelat dhe dosjet që ndani përmes lidhjesh",
    "An error occurred while updating share state: {message}" : "Ndodhi një gabim teksa përditësohej gjendja e ndarjes: {message}",
    "Accept Share" : "Pranoje Ndarjen",
    "Decline Share" : "Hidhe Poshtë Ndarjen",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Doni të shtohet ndarja e largët {name} nga {owner}@{remote}?",
    "Remote share" : "Ndarje e largët",
    "Remote share password" : "Fjalëkalim ndarjeje të largët",
    "Cancel" : "Anuloje",
    "Add remote share" : "Shtoni ndarje të largët",
    "You can upload into this folder" : "Mund të ngarkoni te kjo dosje",
    "No ownCloud installation (7 or higher) found at {remote}" : "Te {remote} s’u gjet instalim ownCloud (7 ose më sipër)",
    "Invalid ownCloud url" : "URL ownCloud e pavlefshme",
    "Share" : "Ndaje me të tjerë",
    "No expiration date set" : "S’ka të caktuar datë skadimi",
    "Declined" : "Hedhur Poshtë",
    "Pending" : "Në pritje",
    "Shared by" : "Ndarë nga",
    "Sharing" : "Ndarje me të tjerë",
    "A file or folder has been <strong>shared</strong>" : "U <strong>nda me të tjerë</strong> një kartelë ose dosje",
    "A file or folder was shared from <strong>another server</strong>" : "Një kartelë ose dosje u nda prej një <strong>shërbyesi tjetër</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "<strong>U shkarkua</strong> një kartelë ose dosje e ndarë me të tjerët publikisht",
    "You received a new remote share %2$s from %1$s" : "Morët një ndarje të largët %2$s nga %1$s",
    "You received a new remote share from %s" : "Morët një ndarje të largët nga %s",
    "%1$s accepted remote share %2$s" : "%1$s pranoi ndarjen e largët %2$s",
    "%1$s declined remote share %2$s" : "%1$s hodhi tej ndarjen e largët %2$s",
    "%1$s unshared %2$s from you" : "%1$s hoqi ndarjen me ju të %2$s",
    "Public shared folder %1$s was downloaded" : "U shkarkua dosja e ndarë publikisht %1$s",
    "Public shared file %1$s was downloaded" : "U shkarkua kartela e ndarë publikisht %1$s",
    "You shared %1$s with %2$s" : "Ndatë %1$s me %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s ndau %1$s me %3$s",
    "You removed the share of %2$s for %1$s" : "Hoqët ndarjen e %2$s për %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s hoqi ndarjen e %3$s për %1$s",
    "You unshared %1$s shared by %2$s from self" : "I hoqët vetes ndarjen %1$s ndarë me ju nga %2$s",
    "You shared %1$s with group %2$s" : "Ndatë %1$s me grupin %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s ndau %1$s me grupin %3$s",
    "You removed the share of group %2$s for %1$s" : "Hoqët ndarjen e grupit %2$s për %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s hoqi ndarjen e grupit %3$s për %1$s",
    "%2$s shared %1$s via link" : "%2$s ndau %1$s përmes një lidhjeje",
    "You shared %1$s via link" : "Ndatë %1$s përmes një lidhjeje",
    "You removed the public link for %1$s" : "Hoqët lidhjen publike për %1$s",
    "%2$s removed the public link for %1$s" : "%2$s hoqi lidhjen publike për %1$s",
    "Your public link for %1$s expired" : "Lidhja juaj publike për %1$s skadoi",
    "The public link of %2$s for %1$s expired" : "Lidhja publike e %2$s për %1$s skadoi",
    "%2$s shared %1$s with you" : "%2$s ndau %1$s me ju",
    "%2$s removed the share for %1$s" : "%2$s hoqi ndarjen për %1$s",
    "Downloaded via public link" : "Shkarkuar përmes një lidhjeje publike",
    "Shared with %2$s" : "U nda me %2$s",
    "Shared with %3$s by %2$s" : "U nda me %3$s nga %2$s",
    "Removed share for %2$s" : "Hoqi ndarjen për %2$s",
    "%2$s removed share for %3$s" : "%2$s hoqi ndarjen për %3$s",
    "Unshared %1$s from self" : "I hoqët vetes ndarjen %1$s",
    "Shared with group %2$s" : "U nda me grupin %2$s",
    "Shared with group %3$s by %2$s" : "U nda me grupin %3$s nga %2$s",
    "Removed share of group %2$s" : "Hoqi ndarjen e grupit %2$s",
    "%2$s removed share of group %3$s" : "%2$s hoqi ndarjen e grupit %3$s",
    "Shared via link by %2$s" : "U nda përmes një lidhje nga %2$s",
    "Shared via public link" : "U nda përmes një lidhje publike",
    "Removed public link" : "Hoqi lidhje publike",
    "%2$s removed public link" : "%2$s hoqi lidhje publike",
    "Public link expired" : "Lidhja publike skadoi",
    "Public link of %2$s expired" : "Lidhja publike e %2$s skadoi",
    "Shared by %2$s" : "U nda nga %2$s",
    "Shares" : "Ndarje",
    "File sharing" : "Ndarje kartelash me të tjerët",
    "Public link" : "Lidhje publike",
    "Couldn't send mail to following recipient(s): %s " : "S’u dërgua dot postë te marrësi(t) vijues: %s ",
    "Share API is disabled" : "API i ndarjeve është çaktivizuar",
    "Wrong share ID, share doesn't exist" : "ID e gabuar ndarjeje, ndarja s’ekziston",
    "Could not delete share" : "Ndarja s’u fshi dot",
    "Please specify a file or folder path" : "Ju lutemi, tregoni një shteg kartele ose dosjeje",
    "Wrong path, file/folder doesn't exist" : "Shteg i gabuar, kratela/dosja s’ekziston",
    "Invalid date, date format must be YYYY-MM-DD" : "Datë e pavlefshme, formati i datës duhet të jetë VVVV-MM-DD",
    "Please specify a valid user" : "Ju lutemi, tregoni një përdorues të vlefshëm",
    "Group sharing is disabled by the administrator" : "Ndarja në grup është çaktivizuar nga përgjegjësi",
    "Please specify a valid group" : "Ju lutemi, tregoni një grup të vlefshëm",
    "The group is blacklisted for sharing" : "Grupit i është ndaluar shkëmbimi",
    "Public link sharing is disabled by the administrator" : "Ndarja e lidhjeve publike është çaktivizuar nga përgjegjësi",
    "Public upload disabled by the administrator" : "Ngarkimi publik është çaktivizuar nga përgjegjësi",
    "Public upload is only possible for publicly shared folders" : "Ngarkimi publik është i mundshëm vetëm për dosje të ndara publikisht",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Ndarja e %s dështoi, ngaqë pjesa përgjegjëse e shërbyesit nuk lejon ndarje prej llojit %s",
    "Unknown share type" : "Lloj i panjohur ndarjesh",
    "Not a directory" : "S’është drejtori",
    "Could not lock path" : "S’u kyç dot shtegu",
    "Could not update share" : "S’u përditësua dot ndarja",
    "Can't change permissions for public share links" : "S’mund të ndryshohen lejet për lidhje ndarjesh publike",
    "Only recipient can change accepted state" : "Gjendjen e pranimit mund ta ndryshojnë vetëm marrësi",
    "\"%1$s\" shared \"%3$s\" with you (on behalf of \"%2$s\")" : "\"%1$s\" ndau me ju \"%3$s\" (në emër të \"%2$s\")",
    "\"%1$s\" shared \"%3$s\" with you" : "\"%1$s\" ndau \"%3$s\" me ju",
    "\"%1$s\" invited you to view \"%3$s\" (on behalf of \"%2$s\")" : "\"%1$s\" ju ftoi të shihni \"%3$s\" (në emër të \"%2$s\")",
    "\"%1$s\" invited you to view \"%3$s\"" : "\"%1$s\" ju ftoi të shihni \"%3$s\"",
    "Accept" : "Pranoje",
    "Decline" : "Hidhe poshtë",
    "Automatically accept new incoming local user shares" : "Prano vetvetiu ndarje të reja që vijnë nga përdorues vendorë",
    "Allow finding you via autocomplete in share dialog. If this is disabled the full username needs to be entered." : "Lejoni gjetjen tuaj përmes vetëplotësimi te dialogu i ndarjeve me të tjerët. Nëse kjo është e çaktivizuar, do të duhet të jepen emra përdoruesish.",
    "This share is password-protected" : "Kjo ndarje është e mbrojtur me fjalëkalim",
    "The password is wrong. Try again." : "Fjalëkalimi është i gabuar. Riprovoni.",
    "Password" : "Fjalëkalim",
    "No entries found in this folder" : "S’u gjetën zëra në këtë dosje",
    "Name" : "Emër",
    "State" : "Gjendje",
    "Share time" : "Kohë ndarjeje",
    "Expiration date" : "Datë skadimi",
    "Sorry, this link doesn’t seem to work anymore." : "Na ndjeni, kjo lidhje duket se nuk funksionon më.",
    "Reasons might be:" : "Arsyet mund të jenë:",
    "the item was removed" : "objekti është hequr",
    "the link expired" : "lidhja ka skaduar",
    "sharing is disabled" : "ndarjet janë çaktivizuar",
    "For more info, please ask the person who sent this link." : "Për më shumë të dhëna, ju lutemi, pyetni personin që ju dërgoi këtë lidhje.",
    "%s is publicly shared" : "%s ndahet publikisht me të tjerët",
    "Download" : "Shkarko",
    "Download %s" : "Shkarko %s",
    "Direct link" : "Lidhje e drejtpërdrejtë",
    "Nothing to configure." : "S’ka gjë për formësim.",
    "Group Sharing Blacklist" : "Listë Bllokimesh Grupesh Ndarjesh",
    "Exclude groups from receiving shares" : "Përjashto grupe nga marrje ndarjesh",
    "These groups will not be available to share with. Members of the group are not restricted in initiating shares and can receive shares with other groups they are a member of as usual." : "Për këto grupe nuk do të jetë e mundur të ndajnë me të tjerët. Anëtarët e grupit nuk janë të kufizuar të nisin ndarje dhe mund të marrin ndarje me grupe të tjerë te të cilët janë anëtarë, si zakonisht."
},
"nplurals=2; plural=(n != 1);");
